@@ -2,9 +2,12 @@
 
 """
 
-from numpy import tan, cos, pi, sin, arccos, clip, mod, minimum, exp, log, \
-    array
-from pandas import to_numeric
+from numpy import tan, cos, pi, sin, arccos, mod, exp, log, nanmax, isnan, \
+    where
+
+from pandas import to_numeric, Series
+
+from xarray import DataArray
 
 # Specific heat of air [MJ kg-1 °C-1]
 CP = 1.013 * 10 ** -3
@@ -15,14 +18,15 @@ def calc_psy(pressure, tmean=None):
 
     Parameters
     ----------
-    pressure: float
+    pressure: float/pandas.Series/xarray.DataArray
         atmospheric pressure [kPa].
-    tmean: float, optional
+    tmean: float/pandas.Series/xarray.DataArray
         average day temperature [°C].
 
     Returns
     -------
-        pandas.Series containing the Psychrometric constant [kPa °C-1].
+        float/pandas.Series/xarray.DataArray containing the Psychrometric
+        constant [kPa °C-1].
 
     Examples
     --------
@@ -31,16 +35,10 @@ def calc_psy(pressure, tmean=None):
     Notes
     -----
     if tmean is none:
-        Based on equation 8 in [allen_1998]_.
+        Based on equation 8 in :cite:t:`allen_crop_1998`.
     elif rh is None:
         From FAO (1990), ANNEX V, eq. 4.
 
-    References
-    ----------
-    .. [allen_1998] Allen, R. G., Pereira, L. S., Raes, D., & Smith, M. (1998).
-       Crop evapotranspiration-Guidelines for computing crop water
-       requirements-FAO Irrigation and drainage paper 56. Fao, Rome, 300.
-       (http://www.fao.org/3/x0490e/x0490e06.htm#TopOfPage).
     """
     if tmean is None:
         return 0.000665 * pressure
@@ -54,13 +52,13 @@ def calc_vpc(tmean):
 
     Parameters
     ----------
-    tmean: pandas.Series, optional
+    tmean: float/pandas.Series/xarray.DataArray
         average day temperature [°C]
 
     Returns
     -------
-        pandas.Series containing the calculated Saturation vapour pressure
-        [kPa °C-1].
+        float/pandas.Series/xarray.DataArray containing the calculated
+        Saturation vapour pressure [kPa °C-1].
 
     Examples
     --------
@@ -68,24 +66,25 @@ def calc_vpc(tmean):
 
     Notes
     -----
-    Based on equation 13. in [allen_1998]_.
+    Based on equation 13. in :cite:t:`allen_crop_1998`.
+
     """
     es = calc_e0(tmean)
     return 4098 * es / (tmean + 237.3) ** 2
 
 
 def calc_lambda(tmean):
-    """ Latent Heat of Vaporization [MJ kg-1].
+    """Latent Heat of Vaporization [MJ kg-1].
 
     Parameters
     ----------
-    tmean: pandas.Series/float, optional
+    tmean: float/pandas.Series/xarray.DataArray
         average day temperature [°C]
 
     Returns
     -------
-    pandas.Series containing the calculated Latent Heat of Vaporization
-        [MJ kg-1].
+    float/pandas.Series/xarray.DataArray containing the calculated Latent Heat
+        of Vaporization [MJ kg-1].
 
     Examples
     --------
@@ -93,22 +92,25 @@ def calc_lambda(tmean):
 
     Notes
     -----
-    Based on equation (3-1) in [allen_1998]_.
+    Based on equation (3-1) in :cite:t:`allen_crop_1998`.
+
     """
     return 2.501 - 0.002361 * tmean
 
 
-def calc_press(elevation):
+def calc_press(elevation, pressure=None):
     """Atmospheric pressure [kPa].
 
     Parameters
     ----------
-    elevation: float, optional
+    elevation: float/xarray.DataArray
         the site elevation [m]
-
+    pressure: float/xarray.DataArray, optional
+        atmospheric pressure [kPa].
     Returns
     -------
-    pandas.Series containing the calculated atmospheric pressure [kPa].
+    float/xarray.DataArray containing the calculated atmospheric
+        pressure [kPa].
 
     Examples
     --------
@@ -116,26 +118,32 @@ def calc_press(elevation):
 
     Notes
     -----
-    Based on equation 7 in [allen_1998]_.
+    Based on equation 7 in :cite:t:`allen_crop_1998`.
+
     """
-    return 101.3 * ((293 - 0.0065 * elevation) / 293) ** 5.26
+    if pressure is None:
+        return 101.3 * ((293 - 0.0065 * elevation) / 293) ** 5.26
+    else:
+        return pressure
 
 
 def calc_rho(pressure, tmean, ea):
-    """atmospheric air density calculated according to [allen_1998]_..
+    """Atmospheric air density calculated according to
+    :cite:t:`allen_crop_1998`.
 
     Parameters
     ----------
-    pressure: pandas.Series/float
+    pressure: float/pandas.Series/xarray.DataArray
         atmospheric pressure [kPa]
-    tmean: pandas.Series/float, optional
+    tmean: float/pandas.Series/xarray.DataArray
         average day temperature [°C]
-    ea: pandas.Series/float, optional
+    ea: float/pandas.Series/xarray.DataArray
         actual vapour pressure [kPa]
 
     Returns
     -------
-    pandas.Series containing the calculated mean air density
+    float/pandas.Series/xarray.DataArray containing the calculated mean
+        air density [kg/m3]
 
     Examples
     --------
@@ -143,20 +151,22 @@ def calc_rho(pressure, tmean, ea):
 
     Notes
     -----
-    Based on equation (3-5) in [allen_1998]_.
+    Based on equation (3-5) in :cite:t:`allen_crop_1998`.
 
     .. math:: rho = 3.486 \\frac{P}{T_{KV}}
+
     """
+    # Virtual temperature [tkv]
     tkv = (273.16 + tmean) * (1 - 0.378 * ea / pressure) ** -1
     return 3.486 * pressure / tkv
 
 
 def calc_e0(tmean):
-    """ Saturation vapor pressure at the air temperature T [kPa].
+    """Saturation vapor pressure at the air temperature T [kPa].
 
     Parameters
     ----------
-    tmean: pandas.Series, optional
+    tmean: float/pandas.Series/xarray.DataArray
         average day temperature [°C]
 
     Returns
@@ -170,26 +180,28 @@ def calc_e0(tmean):
 
     Notes
     -----
-    Based on equation 11 in [allen_1998]_.
+    Based on equation 11 in :cite:t:`allen_crop_1998`.
+
     """
     return 0.6108 * exp(17.27 * tmean / (tmean + 237.3))
 
 
 def calc_es(tmean=None, tmax=None, tmin=None):
-    """ Saturation vapor pressure [kPa].
+    """Saturation vapor pressure [kPa].
 
     Parameters
     ----------
-    tmean: pandas.Series, optional
+    tmean: float/pandas.Series/xarray.DataArray, optional
         average day temperature [°C]
-    tmax: pandas.Series, optional
+    tmax: float/pandas.Series/xarray.DataArray, optional
         maximum day temperature [°C]
-    tmin: pandas.Series, optional
+    tmin: float/pandas.Series/xarray.DataArray, optional
         minimum day temperature [°C]
 
     Returns
     -------
-    pandas.Series containing the calculated saturation vapor pressure [kPa].
+    float/pandas.Series/xarray.DataArray containing the calculated
+        saturation vapor pressure [kPa].
 
     Examples
     --------
@@ -197,7 +209,8 @@ def calc_es(tmean=None, tmax=None, tmin=None):
 
     Notes
     -----
-    Based on equation 11, 12 in [allen_1998]_.
+    Based on equation 11, 12 in :cite:t:`allen_crop_1998`.
+
     """
     if tmax is not None:
         eamax = calc_e0(tmax)
@@ -207,27 +220,31 @@ def calc_es(tmean=None, tmax=None, tmin=None):
         return calc_e0(tmean)
 
 
-def calc_ea(tmean=None, tmax=None, tmin=None, rhmax=None, rhmin=None, rh=None):
-    """ Actual vapor pressure [kPa].
+def calc_ea(tmean=None, tmax=None, tmin=None, rhmax=None, rhmin=None, rh=None,
+            ea=None):
+    """Actual vapor pressure [kPa].
 
     Parameters
     ----------
-    tmean: pandas.Series, optional
+    tmean: float/pandas.Series/xarray.DataArray, optional
         average day temperature [°C]
-    tmax: pandas.Series, optional
+    tmax: float/pandas.Series/xarray.DataArray, optional
         maximum day temperature [°C]
-    tmin: pandas.Series, optional
+    tmin: float/pandas.Series/xarray.DataArray, optional
         minimum day temperature [°C]
-    rhmax: pandas.Series, optional
+    rhmax: float/pandas.Series/xarray.DataArray, optional
         maximum daily relative humidity [%]
-    rhmin: pandas.Series, optional
+    rhmin: float/pandas.Series/xarray.DataArray, optional
         mainimum daily relative humidity [%]
-    rh: pandas.Series, optional
+    rh: float/pandas.Series/xarray.DataArray, optional
         mean daily relative humidity [%]
+    ea: pandas.Series/float, optional
+        actual vapor pressure [kPa]
 
     Returns
     -------
-    pandas.Series containing the calculated actual vapor pressure [kPa].
+    float/pandas.Series/xarray.DataArray containing the calculated actual
+        vapor pressure [kPa].
 
     Examples
     --------
@@ -235,8 +252,11 @@ def calc_ea(tmean=None, tmax=None, tmin=None, rhmax=None, rhmin=None, rh=None):
 
     Notes
     -----
-    Based on equation 17, 19 in [allen_1998]_.
+    Based on equation 17, 19 in :cite:t:`allen_crop_1998`.
+
     """
+    if ea is not None:
+        return ea
     if rhmax is not None:  # eq. 11
         esmax = calc_e0(tmax)
         esmin = calc_e0(tmin)
@@ -254,14 +274,14 @@ def day_of_year(tindex):
 
     Parameters
     ----------
-    tindex: pandas.Index
+    tindex: pandas.DatetimeIndex
 
     Returns
     -------
-    array of with ints specifying day of year.
+    pandas.Series with ints specifying day of year.
 
     """
-    return to_numeric(tindex.strftime('%j'))
+    return Series(to_numeric(tindex.strftime('%j')), tindex, dtype=int)
 
 
 def daylight_hours(tindex, lat):
@@ -269,22 +289,30 @@ def daylight_hours(tindex, lat):
 
     Parameters
     ----------
-    tindex: pandas.Index
-    lat: float
+    tindex: pandas.DatetimeIndex
+    lat: float/xarray.DataArray
         the site latitude [rad]
 
     Returns
     -------
-    pandas.Series containing the calculated daylight hours [hour]
+    pandas.Series or xarray.DataArray containing the calculated
+    daylight hours [hour]
 
     Notes
     -----
-    Based on equation 34 in [allen_1998]_.
+    Based on equation 34 in :cite:t:`allen_crop_1998`.
+
     """
     j = day_of_year(tindex)
     sol_dec = solar_declination(j)
     sangle = sunset_angle(sol_dec, lat)
-    return 24 / pi * sangle
+    # Account for subpolar belt which returns NaN values
+    dl = 24 / pi * sangle
+    if isinstance(lat, DataArray):
+        sol_dec = ((dl / dl).T * sol_dec.values).T
+    dl = where((sol_dec > 0) & (isnan(dl)), nanmax(dl), dl)
+    dl = where((sol_dec < 0) & (isnan(dl)), 0, dl)
+    return dl
 
 
 def sunset_angle(sol_dec, lat):
@@ -292,72 +320,31 @@ def sunset_angle(sol_dec, lat):
 
     Parameters
     ----------
-    sol_dec: pandas.Series
+    sol_dec: float/pandas.Series/xarray.DataArray
         solar declination [rad]
-    lat: float
+    lat: float/xarray.DataArray
         the site latitude [rad]
 
     Returns
     -------
-    pandas.Series containing the calculated sunset hour angle - daily [rad]
+    pandas.Series/xarray.DataArray containing the calculated sunset hour
+    angle - daily [rad]
 
     Notes
     -----
-    Based on equations 25 in [allen_1998]_.
+    Based on equations 25 in :cite:t:`allen_crop_1998`.
+
     """
-    return arccos(-tan(sol_dec) * tan(lat))
-
-
-def sunset_angle_hour(tindex, lat, lz, lon):
-    """Sunset hour angle from latitude and solar declination - hourly [rad].
-
-    Parameters
-    ----------
-    tindex: pandas.Index
-    lat: float
-        the site latitude [rad]
-    lz: float
-        longitude of the center of the local time zone [expressed as positive
-        degrees west of Greenwich, England]. In the United States, Lz = 75, 90,
-        105 and 120° for the Eastern, Central, Rocky Mountain and Pacific time
-        zones, respectively, and Lz = 0° for Greenwich, 345° for Paris
-        (France), and 255° for Bangkok (Thailand) [deg]
-    lon: float
-        longitude of the solar radiation measurement site [expressed as
-        positive degrees west of Greenwich, England]
-
-    Returns
-    -------
-    pandas.Series containing the calculated sunset hour angle - hourly [rad]
-
-    Notes
-    -----
-    Based on equations 29, 30, 31, 32, 33 in [allen_1998]_.
-    """
-    t = tindex.hour - 0.5
-    j = day_of_year(tindex)
-    b = 2 * pi * (j - 81) / 364
-    sc = 0.1645 * sin(2 * b) - 0.1255 * cos(b) - 0.025 * sin(b)
-
-    sol_t = t + 0.006667 * (lz - lon) + sc - 12
-
-    omega = array(pi / 12 * sol_t)
-    omega = _wrap(omega, -pi, pi)
-
-    sol_dec = solar_declination(j)
-    omegas = arccos(clip(-tan(lat) * tan(sol_dec), -1, 1))
-
-    omega1 = omega - (pi / 24)
-    omega2 = omega + (pi / 24)
-
-    omega1 = clip(omega1, -omegas, omegas)
-    omega2 = clip(omega2, -omegas, omegas)
-    omega1 = minimum(omega1, omega2)
-    return array(omega1), array(omega2)
+    if isinstance(lat, DataArray):
+        lat = lat.expand_dims(dim={"time": sol_dec.index}, axis=0)
+        return arccos(-tan(sol_dec.values) * tan(lat).T).T
+    else:
+        return arccos(-tan(sol_dec) * tan(lat))
 
 
 def _wrap(x, x_min, x_max):
-    """Wrap floating point values into range - github.com/WSWUP/RefET
+    """Wrap floating point values into range - github.com/WSWUP/RefET.
+
     Parameters
     ----------
     x : ndarray
@@ -366,9 +353,11 @@ def _wrap(x, x_min, x_max):
         Minimum value in output range.
     x_max : float
         Maximum value in output range.
+
     Returns
     -------
     ndarray
+
     """
     return mod((x - x_min), (x_max - x_min)) + x_min
 
@@ -378,15 +367,16 @@ def solar_declination(j):
 
     Parameters
     ----------
-    j: array.py
+    j: pandas.Series
         day of the year (1-365)
     Returns
     -------
-    array.py of solar declination [rad].
+    pandas.Series of solar declination [rad].
 
     Notes
     -------
-    Based on equations 24 in [allen_1998]_.
+    Based on equations 24 in :cite:t:`allen_crop_1998`.
+
     """
     return 0.409 * sin(2. * pi / 365. * j - 1.39)
 
@@ -396,15 +386,17 @@ def relative_distance(j):
 
     Parameters
     ----------
-    j: array.py
+    j: pandas.Series
         day of the year (1-365)
+
     Returns
     -------
-    array.py specifyng relative distance between earth and sun.
+    pandas.Series specifying relative distance between earth and sun.
 
     Notes
     -------
-    Based on equations 23 in [allen_1998]_.
+    Based on equations 23 in :cite:t:`allen_crop_1998`.
+
     """
     return 1 + 0.033 * cos(2. * pi / 365. * j)
 
@@ -414,108 +406,75 @@ def extraterrestrial_r(tindex, lat):
 
     Parameters
     ----------
-    tindex: pandas.Index
-    lat: float
+    tindex: pandas.DatetimeIndex
+    lat: float/xarray.DataArray
         the site latitude [rad]
 
     Returns
     -------
-    pandas.Series containing the calculated extraterrestrial radiation
+    pandas.Series/xarray.DataArray containing the calculated extraterrestrial
+        radiation [MJ m-2 d-1]
 
     Notes
     -----
-    Based on equation 21 in [allen_1998]_.
-    """
-    j = day_of_year(tindex)
-    dr = relative_distance(j)
-    sol_dec = solar_declination(j)
-
-    omega = sunset_angle(sol_dec, lat)
-    xx = sin(sol_dec) * sin(lat)
-    yy = cos(sol_dec) * cos(lat)
-    return 118.08 / 3.141592654 * dr * (omega * xx + yy * sin(omega))
-
-
-def extraterrestrial_r_hour(tindex, lat, lz, lon):
-    """Extraterrestrial hourly radiation [MJ m-2 h-1].
-
-    Parameters
-    ----------
-    tindex: pandas.Index
-    lat: float
-        the site latitude [rad]
-    lz: float
-        longitude of the center of the local time zone [expressed as positive
-        degrees west of Greenwich, England]. In the United States, Lz = 75, 90,
-        105 and 120° for the Eastern, Central, Rocky Mountain and Pacific time
-        zones, respectively, and Lz = 0° for Greenwich, 345° for Paris
-        (France), and 255° for Bangkok (Thailand)
-    lon: float
-        longitude of the solar radiation measurement site [expressed as
-        positive degrees west of Greenwich, England]
-
-    Returns
-    -------
-    pandas.Series containing the calculated extraterrestrial radiation
-
-    Notes
-    -----
-    Based on equation 55 in [ASCE_2000]_.
+    Based on equation 21 in :cite:t:`allen_crop_1998`.
 
     """
     j = day_of_year(tindex)
     dr = relative_distance(j)
     sol_dec = solar_declination(j)
 
-    omega1, omega2 = sunset_angle_hour(tindex, lat, lz, lon)
-    xx = sin(sol_dec) * sin(lat)
-    yy = cos(sol_dec) * cos(lat)
-    gsc = 4.92
-    return array(12 / pi * gsc * dr * ((omega2 - omega1) * xx + yy *
-                                       (sin(omega2) - sin(omega1))))
+    omega = sunset_angle(sol_dec, lat).values
+    if isinstance(lat, DataArray):
+        lat = lat.expand_dims(dim={"time": sol_dec.index}, axis=0)
+        xx = (sin(sol_dec.values) * sin(lat.T))
+        yy = (cos(sol_dec.values) * cos(lat.T))
+        return (118.08 / 3.141592654 * dr.values * (
+                omega.T * xx + yy * sin(omega.T))).T
+    else:
+        xx = sin(sol_dec) * sin(lat)
+        yy = cos(sol_dec) * cos(lat)
+        return 118.08 / 3.141592654 * dr * (omega * xx + yy * sin(omega))
 
 
-def calc_res_surf(lai=None, r_s=70, r_l=100, lai_eff=0, srs=None, co2=None):
+def calc_res_surf(lai=None, r_s=None, srs=0.002, co2=300, r_l=100, lai_eff=0,
+                  croph=0.12):
     """Surface resistance [s m-1].
 
     Parameters
     ----------
-    lai: pandas.Series/float, optional
+    lai: float/pandas.Series/xarray.DataArray, optional
         leaf area index [-]
-    r_s: pandas.series/float, optional
+    r_s: float/pandas.Series/xarray.DataArray, optional
         surface resistance [s m-1]
-    r_l: float, optional
+    r_l: float/pandas.Series/xarray.DataArray, optional
         bulk stomatal resistance [s m-1]
     lai_eff: float, optional
         1 => LAI_eff = 0.5 * LAI
         2 => LAI_eff = lai / (0.3 * lai + 1.2)
         3 => LAI_eff = 0.5 * LAI; (LAI>4=4)
-        4 => see [zhang_2008]_.
-    srs: float, optional
-        Relative sensitivity of rl to Δ[CO2] [yang_2019]_
-    co2: float
+        4 => see :cite:t:`zhang_comparison_2008`.
+    srs: float/pandas.Series/xarray.DataArray, optional
+        Relative sensitivity of rl to Δ[CO2] :cite:t:`yang_hydrologic_2019`
+    co2: float/pandas.Series/xarray.DataArray
         CO2 concentration [ppm]
+    croph: float/pandas.Series/xarray.DataArray, optional
+        crop height [m]
 
     Returns
     -------
-    pandas.Series containing the calculated surface resistance
-
-    References
-    -----
-    .. [zhang_2008] Zhang, B., Kang, S., Li, F., & Zhang, L. (2008). Comparison
-       of three evapotranspiration models to Bowen ratio-energy balance method
-       for a vineyard in an arid desert region of northwest China. Agricultural
-       and Forest Meteorology, 148(10), 1629-1640.
-    .. [yang_2019] Yang, Y., Roderick, M. L., Zhang, S., McVicar, T. R., &
-       Donohue, R. J. (2019). Hydrologic implications of vegetation response to
-       elevated CO 2 in climate projections. Nature Climate Change, 9, 44-48.
+    float/pandas.Series/xarray.DataArray containing the calculated surface
+        resistance [s / m]
 
     """
-    if lai is None:
+    if r_s:
         return r_s
     else:
         fco2 = (1 + srs * (co2 - 300))
-        return fco2 * r_l / calc_laieff(lai=lai, lai_eff=lai_eff)
+        if lai is None:
+            return fco2 * r_l / (0.5 * croph * 24)  # after FAO-56
+        else:
+            return fco2 * r_l / calc_laieff(lai=lai, lai_eff=lai_eff)
 
 
 def calc_laieff(lai=None, lai_eff=0):
@@ -529,11 +488,12 @@ def calc_laieff(lai=None, lai_eff=0):
         0 => LAI_eff = 0.5 * LAI
         1 => LAI_eff = lai / (0.3 * lai + 1.2)
         2 => LAI_eff = 0.5 * LAI; (LAI>4=4)
-        3 => see [zhang_2008]_.
+        3 => see :cite:t:`zhang_comparison_2008`.
 
     Returns
     -------
     pandas.Series containing the calculated effective leaf area index
+
     """
     if lai_eff == 0:
         return 0.5 * lai
@@ -550,27 +510,29 @@ def calc_laieff(lai=None, lai_eff=0):
         return laie * 0.5
 
 
-def calc_res_aero(wind, croph=None, zw=2, zh=2, ra_method=1):
+def calc_res_aero(wind, croph=0.12, zw=2, zh=2, ra_method=0):
     """Aerodynamic resistance [s m-1].
 
     Parameters
     ----------
-    wind: pandas.Series
+    wind: float/pandas.Series/xarray.DataArray
         mean day wind speed [m/s]
-    croph: pandas.series/float, optional
+    croph: float/pandas.Series/xarray.DataArray, optional
         crop height [m]
     zw: float, optional
         height of wind measurement [m]
     zh: float, optional
          height of humidity and or air temperature measurement [m]
     ra_method: float, optional
-        1 => ra = 208/wind
-        2 => ra is calculated based on equation 36 in FAO (1990), ANNEX V.
+        0 => ra = 208/wind
+        1 => ra is calculated based on equation 36 in FAO (1990), ANNEX V.
+
     Returns
     -------
     pandas.Series containing the calculated aerodynamic resistance
+
     """
-    if ra_method == 1:
+    if ra_method == 0:
         return 208 / wind
     else:
         d = 0.667 * croph
